==> Evergreen-ILS-3.14.11.tar.gz: Evergreen-ILS-3.14.11/Open-ILS/web/js/dojo/openils/opac/nls/es-es/opac.js <==
{
    ":BARCODE_PROMPT": "C\u00f3digo de barras: ",
    ":USERNAME_PROMPT": "Username: ",
    ":CANCEL_BUTTON_LABEL": "Cancelar",
    ":SUBMIT_BUTTON_LABEL": "Presentar",
    ":OK": "Aceptar",
    ":PWD_RESET_RESPONSE_TITLE": "Respuesta para el restablecimiento de la contrase\u00f1a",
    ":PWD_RESET_SUBMIT_SUCCESS": "Su solicitud para iniciar el proceso de reinicializacion de contrase\u00f1a a sido procesado. Si su cuenta tiene una direcci\u00f3n de correo electr\u00f3nico v\u00e1lida, usted debe recibir un correo electr\u00f3nico que contiene m\u00e1s instrucciones para reinicializar su contrase\u00f1a.",
    ":PWD_RESET_SUBMIT_ERROR": "El sistema no pudo procesar su solicitud para el restablecimiento de su contrase\u00f1a. Por favor intente de nuevo, o contacte personal de circulaci\u00f3n por asistencia.",
    ":PWD_RESET_SUBMIT_STATUS": "Enviando solicitud...",
    ":PWD_RESET_FORGOT_PROMPT": "Se le olvido la contrase\u00f1a?",
    ":PWD_RESET_FORM_TITLE": "Solicite restablecer la contrase\u00f1a",
    ":PWD_RESET_SUBMIT_PROMPT": "To begin the password reset process, enter either your barcode or username in the form below and click 'Submit'",
    ":CREATE_MFHD": "A\u00f1adir registro MFFHD",
    ":CREATED_MFHD_RECORD": "Se cre\u00f3 un registro MFHD para ${0}",
    ":DELETE_MFHD": "Eliminar registro",
    ":DELETE_MFHD_CONFIRM": "\u00bfEsta seguro de que desea borrar el registro de serie?",
    ":DELETED_MFHD_RECORD": "Eliminar registro MFHD ${0}",
    ":EDIT_MFHD_RECORD": "Editar registro",
    ":EDIT_MFHD_MENU": "Editar Explotaciones",
    ":EDIT_PROPERTIES": "Editar Propiedades",
    ":BASIC_HOLDINGS": "Vol\u00famenes",
    ":BASIC_HOLDINGS_ADD": "Informaci\u00f3n adicional del volumen",
    ":INDEX_HOLDINGS": "\u00cdndices",
    ":INDEX_HOLDINGS_ADD": "Informaci\u00f3n adicional del \u00edndice",
    ":CURRENT_HOLDINGS": "Volumen actual",
    ":CURRENT_INDEXES": "\u00cdndices actuales",
    ":CURRENT_SUPPLEMENTS": "Suplementos actuales",
    ":HOLDINGS_TABLE_CAPTION": "Resumen de las explotaciones (${0})",
    ":INCOMPLETE_VOLUMES": "Vol\u00famenes Incompletos",
    ":MISSING_VOLUMES": "Vol\u00famenes faltantes",
    ":ONLINE_VOLUMES": "Vol\u00famenes en l\u00ednea",
    ":SAVE_MFHD_LABEL": "Guardar MFHD",
    ":SUPPLEMENT_HOLDINGS": "Suplementos",
    ":SUPPLEMENT_HOLDINGS_ADD": "Informaci\u00f3n adicional de suplemento",
    ":PLACE_HOLD": "Reservar",
    ":HOLD_STATUS_PLURAL": "apartado # $(0) de $(1) apartados totales y $(2) ejemplares potenciales",
    ":HOLD_STATUS_SINGULAR": "apartado # $(0) de $(1) apartados totales y $(2) ejemplar potencial",
    ":MORE": "M\u00e1s",
    ":MORE_COPIES_FULL_RECORD": "... m\u00e1s copias que estan listadas en todo el registro",
    ":SOURCE_CANNOT_HAVE_COPIES": "Registros desde ${0} no tienen copias."
}

==> Evergreen-ILS-3.16.2.tar.gz: Evergreen-ILS-3.16.2/Open-ILS/web/js/dojo/openils/opac/nls/es-es/opac.js <==
{
    ":BARCODE_PROMPT": "C\u00f3digo de barras: ",
    ":USERNAME_PROMPT": "Nombre de usuario: ",
    ":CANCEL_BUTTON_LABEL": "Cancelar",
    ":SUBMIT_BUTTON_LABEL": "Presentar",
    ":OK": "Aceptar",
    ":PWD_RESET_RESPONSE_TITLE": "Respuesta para el restablecimiento de la contrase\u00f1a",
    ":PWD_RESET_SUBMIT_SUCCESS": "Su solicitud para iniciar el proceso de reinicializacion de contrase\u00f1a a sido procesado. Si su cuenta tiene una direcci\u00f3n de correo electr\u00f3nico v\u00e1lida, usted debe recibir un correo electr\u00f3nico que contiene m\u00e1s instrucciones para reinicializar su contrase\u00f1a.",
    ":PWD_RESET_SUBMIT_ERROR": "El sistema no pudo procesar su solicitud para el restablecimiento de su contrase\u00f1a. Por favor intente de nuevo, o contacte personal de circulaci\u00f3n por asistencia.",
    ":PWD_RESET_SUBMIT_STATUS": "Enviando solicitud...",
    ":PWD_RESET_FORGOT_PROMPT": "Se le olvido la contrase\u00f1a?",
    ":PWD_RESET_FORM_TITLE": "Solicite restablecer la contrase\u00f1a",
    ":PWD_RESET_SUBMIT_PROMPT": "Para empezar el proceso de restablecer la contrase\u00f1a, ingrese su c\u00f3digo de barras o su nombre de usuario en el formulario debajo y haga clic en 'presentar'",
    ":CREATE_MFHD": "A\u00f1adir registro MFFHD",
    ":CREATED_MFHD_RECORD": "Se cre\u00f3 un registro MFHD para ${0}",
    ":DELETE_MFHD": "Eliminar registro",
    ":DELETE_MFHD_CONFIRM": "\u00bfEsta seguro de que desea borrar el registro de serie?",
    ":DELETED_MFHD_RECORD": "Eliminar registro MFHD ${0}",
    ":EDIT_MFHD_RECORD": "Editar registro",
    ":EDIT_MFHD_MENU": "Editar Explotaciones",
    ":EDIT_PROPERTIES": "Editar Propiedades",
    ":BASIC_HOLDINGS": "Vol\u00famenes",
    ":BASIC_HOLDINGS_ADD": "Informaci\u00f3n adicional del volumen",
    ":INDEX_HOLDINGS": "\u00cdndices",
    ":INDEX_HOLDINGS_ADD": "Informaci\u00f3n adicional del \u00edndice",
    ":CURRENT_HOLDINGS": "Volumen actual",
    ":CURRENT_INDEXES": "\u00cdndices actuales",
    ":CURRENT_SUPPLEMENTS": "Suplementos actuales",
    ":HOLDINGS_TABLE_CAPTION": "Resumen de las explotaciones (${0})",
    ":INCOMPLETE_VOLUMES": "Vol\u00famenes Incompletos",
    ":MISSING_VOLUMES": "Vol\u00famenes faltantes",
    ":ONLINE_VOLUMES": "Vol\u00famenes en l\u00ednea",
    ":SAVE_MFHD_LABEL": "Guardar MFHD",
    ":SUPPLEMENT_HOLDINGS": "Suplementos",
    ":SUPPLEMENT_HOLDINGS_ADD": "Informaci\u00f3n adicional de suplemento",
    ":PLACE_HOLD": "Reservar",
    ":HOLD_STATUS_PLURAL": "apartado # $(0) de $(1) apartados totales y $(2) ejemplares potenciales",
    ":HOLD_STATUS_SINGULAR": "apartado # $(0) de $(1) apartados totales y $(2) ejemplar potencial",
    ":MORE": "M\u00e1s",
    ":MORE_COPIES_FULL_RECORD": "... m\u00e1s copias que estan listadas en todo el registro",
    ":SOURCE_CANNOT_HAVE_COPIES": "Registros desde ${0} no tienen copias."
}
